@@ -6,7 +6,7 @@ qbit::Array - Functions to manipulate dates.
 =cut
 
 package qbit::Date;
-$qbit::Date::VERSION = '2.3';
+$qbit::Date::VERSION = '2.4';
 use strict;
 use warnings;
 use utf8;
@@ -38,7 +38,7 @@ our %TR_HS = (
         '<' => sub {[@{$_[0]}]},
     },
     db => {
-        '>' => sub {sprintf('%04d-%02d-%02d', @{$_[0]})},
+        '>' => sub {sprintf('%04d-%02d-%02d', @{$_[0]}[0 .. 2])},
         '<' => sub {
             shift =~ /\A(\d{4})-(\d{2})-(\d{2})\z/
               ? [$1, $2, $3, 0, 0, 0]
@@ -51,7 +51,7 @@ our %TR_HS = (
         },
         '<' => sub {
             shift =~ /\A(\d{4})-(\d{2})-(\d{2})(?:(?:\s+|T)(\d{1,2}):(\d{1,2}):(\d{1,2}))?\z/
-              ? [$1, $2, $3, $4, $5, $6]
+              ? [$1, $2, $3, $4 // 0, $5 // 0, $6 // 0]
               : [0, 0, 0, 0, 0, 0];
         },
     },
